#[unsafe(no_mangle)]pub extern "C" fn orderbook_best_ask_price(
book: &mut OrderBook_API,
) -> PriceExpand description
Panics
Panics if there are no ask orders for best ask price.
#[unsafe(no_mangle)]pub extern "C" fn orderbook_best_ask_price(
book: &mut OrderBook_API,
) -> PricePanics if there are no ask orders for best ask price.