#[unsafe(no_mangle)]pub extern "C" fn orderbook_best_ask_size(
book: &mut OrderBook_API,
) -> QuantityExpand description
Panics
Panics if there are no ask orders for best ask size.
#[unsafe(no_mangle)]pub extern "C" fn orderbook_best_ask_size(
book: &mut OrderBook_API,
) -> QuantityPanics if there are no ask orders for best ask size.