#[unsafe(no_mangle)]pub extern "C" fn orderbook_best_bid_price(
book: &mut OrderBook_API,
) -> PriceExpand description
Panics
Panics if there are no bid orders for best bid price.
#[unsafe(no_mangle)]pub extern "C" fn orderbook_best_bid_price(
book: &mut OrderBook_API,
) -> PricePanics if there are no bid orders for best bid price.