#[unsafe(no_mangle)]pub extern "C" fn orderbook_best_bid_size(
book: &mut OrderBook_API,
) -> QuantityExpand description
Panics
Panics if there are no bid orders for best bid size.
#[unsafe(no_mangle)]pub extern "C" fn orderbook_best_bid_size(
book: &mut OrderBook_API,
) -> QuantityPanics if there are no bid orders for best bid size.